clc
clear;

%Load data from file:
load Supply_Chain_Toolbox_data.mat

%Define problem statement:
problem_statement = sprintf('%s\n',...
'minimize',...
'  avg(recourse(matrix_xfirst_scp, pmatrix_subproblem_scp, matrix_of_scenarios_scp_75))',...
'Constraint: >= vector_l_scp, <= vector_u_scp',...
'  linearmulti(pmatrix_xmulti_scp)',...
'Box: >= 0, <= 1e+13',...
'Solver: cargrb, precision = 6',...
' ');

%Pack data to PSG structure:
count = 0;
count = count+1;
toolboxstruc_arr(count) = tbpsg_matrix_pack('matrix_xfirst_scp',matrix_xfirst_scp_data,matrix_xfirst_scp_vars);
count = count+1;
toolboxstruc_arr(count) = tbpsg_matrix_pack('matrix_of_scenarios_scp_75',matrix_of_scenarios_scp_75_data,matrix_of_scenarios_scp_75_vars);
count = count+1;
toolboxstruc_arr(count) = tbpsg_pmatrix_pack('pmatrix_subproblem_scp',pmatrix_subproblem_scp_data,pmatrix_subproblem_scp_vars);
count = count+1;
toolboxstruc_arr(count) = tbpsg_pmatrix_pack('pmatrix_xmulti_scp',pmatrix_xmulti_scp_data,pmatrix_xmulti_scp_vars);
count = count+1;
toolboxstruc_arr(count) = tbpsg_vector_pack('vector_l_scp',vector_l_scp_data);
count = count+1;
toolboxstruc_arr(count) = tbpsg_vector_pack('vector_u_scp',vector_u_scp_data);

%Optimize problem using tbpsg_run function:
[solution_str, outargstruc_arr] = tbpsg_run(problem_statement,toolboxstruc_arr);

%Extract Objective:
val_obj = tbpsg_objective(solution_str, outargstruc_arr);

disp(' ');
disp('Objective = ');
disp(val_obj);

%Extract optimal solution:
point_data = tbpsg_optimal_point_data(solution_str, outargstruc_arr);

disp(' ');
disp('Optimal point = ');
disp(point_data);

%Extract structure containing PSG solution reports:
output_structure = tbpsg_solution_struct(solution_str, outargstruc_arr);

disp(' ');
disp('Structure with PSG solution = ');
disp(output_structure);

%=======================================================================|
%American Optimal Decisions, Inc. Copyright                             |
%Copyright American Optimal Decisions, Inc. 2007-2016.                 |
%American Optimal Decisions (AOD) retains copyrights to this material.  |
%                                                                       |
%Permission to reproduce this document and to prepare derivative works  |
%from this document for internal use is granted, provided the copyright |
%and No Warranty  statements are included with all reproductions       |
%and derivative works.                                                  |
%                                                                       |
%For information regarding external or commercial use of copyrighted    |
%materials owned by AOD, contact AOD at support@aorda.com.              |
%=======================================================================|